@@ -29,11 +29,12 @@ def create_yolo(architecture,
                 coord_scale=1.0,
                 class_scale=1.0,
                 object_scale=5.0,
-                no_object_scale=1.0):
+                no_object_scale=1.0,
+                weights=None):
 
     n_classes = len(labels)
     n_boxes = int(len(anchors)/2)
-    yolo_network = create_yolo_network(architecture, input_size, n_classes, n_boxes)
+    yolo_network = create_yolo_network(architecture, input_size, n_classes, n_boxes, weights)
     yolo_loss = YoloLoss(yolo_network.get_grid_size(),
                          n_classes,
                          anchors,
@@ -61,17 +62,16 @@ class YOLO(object):
         self._yolo_network = yolo_network
         self._yolo_loss = yolo_loss
         self._yolo_decoder = yolo_decoder
-        
         self._labels = labels
-        # Batch를 생성할 때만 사용한다.
         self._input_size = input_size
+        self._norm = yolo_network._norm
 
     def load_weights(self, weight_path, by_name=False):
         if os.path.exists(weight_path):
-            print("Loading pre-trained weights in", weight_path)
+            print("Loading pre-trained weights for the whole model: ", weight_path)
             self._yolo_network.load_weights(weight_path, by_name=by_name)
         else:
-            print("Fail to load pre-trained weights-starting training from scratch")
+            print("Failed to load pre-trained weights for the whole model. It might be because you didn't specify any or the weight file cannot be found")
 
     def predict(self, image, height, width, threshold=0.3):
         """
@@ -114,7 +114,8 @@ class YOLO(object):
               valid_times=1,
               valid_img_folder="",
               valid_ann_folder="",
-              first_trainable_layer=None):
+              first_trainable_layer=None,
+              metrics="mAP"):
 
         # 1. get annotations        
         train_annotations, valid_annotations = get_train_annotations(self._labels,
@@ -140,7 +141,8 @@ class YOLO(object):
                 nb_epoch           = nb_epoch,
                 project_folder = project_folder,
                 first_trainable_layer=first_trainable_layer,
-                network=self)
+                network=self,
+                metrics="mAP")
 
     def _get_loss_func(self, batch_size):
         return self._yolo_loss.custom_loss(batch_size)
