@@ -32,7 +32,8 @@ argparser.add_argument(
 
 def train_from_config(config,project_folder):
     # Create the converter
-    converter = Converter(config['converter']['type'])
+    converter = Converter(config['converter']['type'], config['model']['architecture'],
+                          config['model']['input_size'], config['train']['valid_image_folder'])
 
     #  Segmentation network
     if config['model']['type']=='SegNet':
@@ -40,9 +41,10 @@ def train_from_config(config,project_folder):
         # 1. Construct the model 
         segnet = create_segnet(config['model']['architecture'],
                                    config['model']['input_size'],
-                                   config['model']['n_classes'])   
+                                   config['model']['n_classes'],
+                                   config['weights']['backend'])   
         # 2. Load the pretrained weights (if any) 
-        segnet.load_weights(config['pretrained']['full'], by_name=True)
+        segnet.load_weights(config['weights']['full'], by_name=True)
         # 3. actual training 
         model_layers, model_path = segnet.train(config['train']['train_image_folder'],
                                            config['train']['train_annot_folder'],
@@ -56,7 +58,8 @@ def train_from_config(config,project_folder):
                                            config['train']['valid_image_folder'],
                                            config['train']['valid_annot_folder'],
                                            config['train']['first_trainable_layer'],
-                                           config['train']['ignore_zero_class'])
+                                           config['train']['ignore_zero_class'],
+                                           config['train']['valid_metric'])
                
     #  Classifier
     if config['model']['type']=='Classifier':
@@ -70,9 +73,11 @@ def train_from_config(config,project_folder):
                                        labels,
                                        config['model']['input_size'],
                                        config['model']['fully-connected'],
-                                       config['model']['dropout'])   
+                                       config['model']['dropout'],
+                                       config['weights']['backend'],
+                                       config['weights']['save_bottleneck'])   
         # 2. Load the pretrained weights (if any) 
-        classifier.load_weights(config['pretrained']['full'], by_name=True)
+        classifier.load_weights(config['weights']['full'], by_name=True)
 
         # 3. actual training 
         model_layers, model_path = classifier.train(config['train']['train_image_folder'],
@@ -84,7 +89,8 @@ def train_from_config(config,project_folder):
                                                config['train']['train_times'],
                                                config['train']['valid_times'],
                                                config['train']['valid_image_folder'],
-                                               config['train']['first_trainable_layer'])
+                                               config['train']['first_trainable_layer'],
+                                               config['train']['valid_metric'])
 
 
 
@@ -107,10 +113,11 @@ def train_from_config(config,project_folder):
                            config['model']['coord_scale'],
                            config['model']['class_scale'],
                            config['model']['object_scale'],
-                           config['model']['no_object_scale'])
+                           config['model']['no_object_scale'],
+                           config['weights']['backend'])
         
         # 2. Load the pretrained weights (if any) 
-        yolo.load_weights(config['pretrained']['full'], by_name=True)
+        yolo.load_weights(config['weights']['full'], by_name=True)
 
         # 3. actual training 
         model_layers, model_path = yolo.train(config['train']['train_image_folder'],
@@ -124,7 +131,9 @@ def train_from_config(config,project_folder):
                                            config['train']['valid_times'],
                                            config['train']['valid_image_folder'],
                                            config['train']['valid_annot_folder'],
-                                           config['train']['first_trainable_layer'])
+                                           config['train']['first_trainable_layer'],
+                                           config['train']['valid_metric'])
+    # 4 Convert the model
     converter.convert_model(model_path,model_layers,config['train']['valid_image_folder'])    
     return model_path
 
